<?php

namespace App\Wrangler\Components;

use Illuminate\Http\Request;
use Medialight\Textstem\Helpers\DataHelper;
use Medialight\Textstem\Models\Post;
use Medialight\Textstem\Models\WranglerPage;
use Medialight\Textstem\Wrangler\ActiveComponent;

class BlogPost extends ActiveComponent
{
    public static string $description = "Displays specified blog post.";

    public $config;


    public array $editSetup = [
        [
            'controltype' => 'instructions',
            'value' => 'Displays a single blog post',
        ],
        [
            'name' => 'post',
            'controltype' => 'select',
            'value' => '',
            'label' => 'Blog Post',
            'instructions' => 'Optional title. Note - this text will be escaped. To enter raw HTML, use the HTML block.',
            'type' => 'news',
            'options' => 'Medialight\Textstem\Domain\Posts\Helpers\ListPosts'
        ],
//        [
//            'name' => 'post',
//            'controltype' => 'number',
//            'value' => '',
//            'label' => 'Blog Post (ID)',
//            'instructions' => 'Enter the ID of the post',
//            'type' => 'news'
//        ],
        [
            'name' => 'template',
            'controltype' => 'select-template',
            'value' => 'default',
        ],
        [
            'name' => 'url',
            'controltype' => 'text',
            'value' => '',
            'label' => 'View Page Url',
            'instructions' => 'Optional - if not empty, a "view more" button is created linking to this url.',
        ],
    ];

    //    public function __construct($config = [])
    //    {
    //
    //        $this->checkEditorSetup($this->editSetup);
    //
    //        $this->config = $this->setupConfig($config);
    //
    //
    //        foreach ($this->editSetup as $indx => &$setup) {
    //            $field = $setup['name'] ?? 'conf_' . $indx;
    //            if (isset($this->config[$field])) {
    //                // set the value
    //                $setup['value'] = $this->config[$field];
    //            } else {
    //                // look in the data
    //                if (is_array($this->config['data']) && isset($this->config['data'][$field])) {
    //                    $setup['value'] = $this->config['data'][$field];
    //
    //                } else {
    //                   //   \Barryvdh\Debugbar\Facades\Debugbar::addMessage('no value for ' . $field . ' in ', $this->config);
    //                }
    //            }
    //        }
    //
    //    }

    public function render(Request $request, WranglerPage $wranglerPage)
    {

        // trying to look at single view
        $id = DataHelper::castAsId($this->config['post']);
        if ($id > 0) {
            $post = Post::where('id', $id)->public()->first();

        } else {
            $post = Post::where('slug', $id)->public()->first();
        }

        if ($post) {
            $data = [
                'config' => $this->config,
                'post' => $post,
                'title' => $post->title,
                'next' => $this->next($post),
                'previous' => $this->previous($post),
                'route_index' => $wranglerPage->url,
                'route' => $wranglerPage->url .'/' . $post->slug,
            ];
            // now tweak the page
            $pageProps = collect($post);

            // the assumeFeatures method allows the page to take on the features of the post
            $wranglerPage->assumeFeatures($post);

            $view = $this->getView();

            return view("$view", $data)->render();
        } else {
            abort(404);
        }


        $posts = Post::where('post_type', 'news')
            ->public()
            ->orderBy('published_at', 'desc')
            ->paginate($this->config['data']['limit'] ?? 5)
            ->withQueryString();

        $data = [
            'config' => $this->config,
            'posts' => $posts,
            'title' => 'Latest News',
            'route' => $wranglerPage->url // .'/'.($this->config['slug'] ?? $this->config['id']),
        ];
        $view = $this->getView('listtemplate');

        return view("$view", $data)->render();
    }


    // in your model file
    public function next($post)
    {
        // get next post
        return Post::select(['id', 'title', 'slug', 'thumbnail'])
            ->where('post_type', 'news')
            ->where('published_at', '>', $post->published_at)
            ->public()
            ->orderBy('published_at', 'asc')->first();

    }

    public function previous($post)
    {
        // get previous  post
        return Post::select(['id', 'title', 'slug', 'thumbnail'])
            ->where('post_type', 'news')
            ->where('published_at', '<', $post->published_at)
            ->public()
            ->orderBy('published_at', 'desc')->first();

    }


    public function preview()
    {
        return Post::select(['id', 'title', 'slug', 'thumbnail'])
            ->where('post_type', 'news')
            ->orderBy('published_at', 'desc')->first();

        $data = [
            'config' => $this->config,
            'post' => $post,
            'route_index' => '#',
            'route' => '#',
        ];
        //dd($data);
        $view = $this->getView('template');

        return view("$view", $data)->render();
    }


}
